@@ -5,7 +5,6 @@
 #include <stdint.h>
 
 int main(int argc, char **argv){
-
   TCBDB *bdb;
   BDBCUR *cur;
   int ecode;
@@ -15,7 +14,7 @@ int main(int argc, char **argv){
   bdb = tcbdbnew();
 
   /* open the database */
-  if(!tcbdbopen(bdb, "casket.bdb", BDBOWRITER | BDBOCREAT)){
+  if(!tcbdbopen(bdb, "casket.tcb", BDBOWRITER | BDBOCREAT)){
     ecode = tcbdbecode(bdb);
     fprintf(stderr, "open error: %s\n", tcbdberrmsg(ecode));
   }
